@@ -14,7 +14,8 @@ urlpatterns = [
     re_path(r"^password/reset/(?P<uidb36>[0-9A-Za-z]+)-(?P<token>.+)/$",
             password_views.ResetPasswordByLink.as_view(),
             name="link-reset-password"),
-    re_path('registration/', CreateUserWToken.as_view(), name="create-user"),
+    re_path(r'^registration/$', CreateUserWToken.as_view(), name="create-user"),
+    re_path('registration/pin/', password_views.CreateSignupPinSerializer.as_view(), name="create-signup-pin"),
     re_path('email-verify/', account_views.EmailCheck.as_view()),
     re_path(r'^(?P<pk>\d+|self)/$', account_views.UserDetails.as_view(), name="userinfo"),
     re_path('oauth/', include('auth_framework.oauth.urls')),
